django-paste
============

Pluggable, configurable, pastebin HTTP REST API
-----------------------------------------------

*django-paste* is a simple `Django <https://www.djangoproject.com/>`_
pluggable app of a code pasting and highlighting HTTP REST API, written using
`Django REST framework <https://www.django-rest-framework.org/>`_. It supports
the `CRUD <https://en.wikipedia.org/wiki/Create,_read,_update_and_delete>`_
operations on source code snippets and uses any existing user authentication
system. Syntax highlighting is powered by `Pygments
<https://pygments.org/>`_.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   install
   api
   fields
   settings
